Library
-------

.. automodule:: ytmusicapi

    .. automethod:: YTMusic.get_library_playlists
    .. automethod:: YTMusic.get_library_songs
    .. automethod:: YTMusic.get_library_albums
    .. automethod:: YTMusic.get_library_artists
    .. automethod:: YTMusic.get_library_subscriptions
    .. automethod:: YTMusic.get_library_podcasts
    .. automethod:: YTMusic.get_library_channels
    .. automethod:: YTMusic.get_liked_songs
    .. automethod:: YTMusic.get_saved_episodes
    .. automethod:: YTMusic.get_history
    .. automethod:: YTMusic.add_history_item
    .. automethod:: YTMusic.remove_history_items
    .. automethod:: YTMusic.rate_song
    .. automethod:: YTMusic.edit_song_library_status
    .. automethod:: YTMusic.rate_playlist
    .. automethod:: YTMusic.subscribe_artists
    .. automethod:: YTMusic.unsubscribe_artists
    .. automethod:: YTMusic.get_account_info
